@@ -82,11 +82,11 @@ void AddBackupWizard::initView()
 
 void AddBackupWizard::initConnections()
 {
-	connect( addBackupWizard1View->source, TQT_SIGNAL( textChanged(const TQString&)), this, TQT_SLOT( slotPage1Changed() ) );
-	connect( addBackupWizard2View->dest, TQT_SIGNAL( textChanged(const TQString&)), this, TQT_SLOT( slotPage2Changed() ) );
-	connect( addBackupWizard3View->advancedConfig, TQT_SIGNAL( clicked()),this,TQT_SLOT(slotShowAdvancedConfig()));
-	connect( addBackupWizard1View->includeExclude, TQT_SIGNAL( clicked()),this,TQT_SLOT(slotShowIncludeExclude()));
-	connect( finishButton(), TQT_SIGNAL( clicked()), this, TQT_SLOT( slotFinishClicked() ) );
+	connect( addBackupWizard1View->source, TQ_SIGNAL( textChanged(const TQString&)), this, TQ_SLOT( slotPage1Changed() ) );
+	connect( addBackupWizard2View->dest, TQ_SIGNAL( textChanged(const TQString&)), this, TQ_SLOT( slotPage2Changed() ) );
+	connect( addBackupWizard3View->advancedConfig, TQ_SIGNAL( clicked()),this,TQ_SLOT(slotShowAdvancedConfig()));
+	connect( addBackupWizard1View->includeExclude, TQ_SIGNAL( clicked()),this,TQ_SLOT(slotShowIncludeExclude()));
+	connect( finishButton(), TQ_SIGNAL( clicked()), this, TQ_SLOT( slotFinishClicked() ) );
 }
 
 void AddBackupWizard::setupPage1()
