@@ -24,7 +24,7 @@
 
 class BackupListWidget: public BackupListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	BackupListWidget(TQWidget *parent, char *name);
