@@ -28,7 +28,7 @@
 class ForceBackupDialog: public KDialogBase
 {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
