@@ -25,7 +25,7 @@
 
 class LogDialog: public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
