@@ -40,7 +40,7 @@
 RestoreBackupWizard::RestoreBackupWizard(TQWidget *parent,const char* name): KWizard( parent, name, true)
 {
 	m_manager = new RDBManager();
-	connect( m_manager, TQT_SIGNAL(backupError(Backup,TQString)), this, TQT_SLOT(slotRestoreError(Backup,TQString)) );
+	connect( m_manager, TQ_SIGNAL(backupError(Backup,TQString)), this, TQ_SLOT(slotRestoreError(Backup,TQString)) );
 
 	TDEIconLoader icons;
 	this->setIcon( icons.loadIcon( "wizard",TDEIcon::Small ));
@@ -48,9 +48,9 @@ RestoreBackupWizard::RestoreBackupWizard(TQWidget *parent,const char* name): KWi
 
 	m_popup = new TDEPopupMenu(this);
 	m_popup->insertTitle(i18n("Menu"));
-	m_popup->insertItem(i18n("Show differences destination/backup"), this, TQT_SLOT(slotShowDiff()));
-	m_popup->insertItem(i18n("List changed files"), this, TQT_SLOT(slotShowChanged()));
-	m_popup->insertItem(i18n("List files"), this, TQT_SLOT(slotShowList()));
+	m_popup->insertItem(i18n("Show differences destination/backup"), this, TQ_SLOT(slotShowDiff()));
+	m_popup->insertItem(i18n("List changed files"), this, TQ_SLOT(slotShowChanged()));
+	m_popup->insertItem(i18n("List files"), this, TQ_SLOT(slotShowList()));
 
 	setupPage1();
 	setupPage2();
@@ -73,25 +73,25 @@ RestoreBackupWizard::~RestoreBackupWizard()
 void RestoreBackupWizard::initConnections()
 {
 	// If custom source setted
-	connect(restoreBackupWizard1View->btnCustomSource, TQT_SIGNAL( toggled(bool)),this,TQT_SLOT(slotCustomSourceChecked(bool)));
+	connect(restoreBackupWizard1View->btnCustomSource, TQ_SIGNAL( toggled(bool)),this,TQ_SLOT(slotCustomSourceChecked(bool)));
 
 	// Date selection popup menu
-	connect(restoreBackupWizard3View->incrementList, TQT_SIGNAL(contextMenu (TDEListView *, TQListViewItem *, const TQPoint &)), this, TQT_SLOT(slotContextMenu(TDEListView *,TQListViewItem*,const TQPoint&)));
+	connect(restoreBackupWizard3View->incrementList, TQ_SIGNAL(contextMenu (TDEListView *, TQListViewItem *, const TQPoint &)), this, TQ_SLOT(slotContextMenu(TDEListView *,TQListViewItem*,const TQPoint&)));
 
 	// Page 1 changes
-	connect(restoreBackupWizard1View->m_lstBackup,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotPage1Changed()));
-	connect(restoreBackupWizard1View->btnCustomSource,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotPage1Changed()));
-	connect(restoreBackupWizard1View->customSource,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(slotPage1Changed()));
+	connect(restoreBackupWizard1View->m_lstBackup,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotPage1Changed()));
+	connect(restoreBackupWizard1View->btnCustomSource,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotPage1Changed()));
+	connect(restoreBackupWizard1View->customSource,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(slotPage1Changed()));
 
 	// Page 2 changes
-	connect(restoreBackupWizard2View->btnCustomDest,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotPage2Changed()));
-	connect(restoreBackupWizard2View->customDest,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(slotPage2Changed()));
+	connect(restoreBackupWizard2View->btnCustomDest,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotPage2Changed()));
+	connect(restoreBackupWizard2View->customDest,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(slotPage2Changed()));
 	
 	// Page 3 Changes
-	connect(restoreBackupWizard3View->incrementList,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotPage3Changed()));
+	connect(restoreBackupWizard3View->incrementList,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotPage3Changed()));
 	
 	// Finish button
-	connect(finishButton(),TQT_SIGNAL(clicked()),this,TQT_SLOT(slotRestoreBackup()));
+	connect(finishButton(),TQ_SIGNAL(clicked()),this,TQ_SLOT(slotRestoreBackup()));
 }
 
 void RestoreBackupWizard::slotPage1Changed()
@@ -118,7 +118,7 @@ void RestoreBackupWizard::slotPage1Changed()
 	{		
 		RDBManager manager;
 		TQDateTime lastBackup = manager.lastIncrement(b);
-		restoreBackupWizard3View->lblLastBackup->setText(lastBackup.toString(Qt::LocalDate));
+		restoreBackupWizard3View->lblLastBackup->setText(lastBackup.toString(TQt::LocalDate));
 		TQValueList<TQDateTime> increments = manager.incrementList(b);
 		if ( increments.size() != 0 )
 		{
@@ -222,7 +222,7 @@ void RestoreBackupWizard::setupPage3()
 	restoreBackupWizard3View = new RestoreBackupWizard3View(page3,"restoreBackupWizard3View");
 
 	restoreBackupWizard3View->incrementList->setSorting(0,false);
-	restoreBackupWizard3View->lblDate->setText(TQDateTime::currentDateTime().toString(Qt::LocalDate));
+	restoreBackupWizard3View->lblDate->setText(TQDateTime::currentDateTime().toString(TQt::LocalDate));
 	addPage( page3, "Date to restore" );
 }
 
